OC.L10N.register(
    "notes",
    {
    "Notes" : "הערות",
    "The last viewed note cannot be accessed. " : "אין גישה לפתק האחרון שנצפה.",
    "The notes folder is not accessible: %s" : "תיקיית הפתקים אינה נגישה: %s",
    "New note" : "הערה חדשה",
    "Encryption Error" : "שגיאת הצפנה",
    "Error" : "שגיאה",
    "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
    "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
    "Settings" : "הגדרות",
    "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
    "path to notes" : "נתיב לפתקיות",
    "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
    "All notes" : "כל הפתקים",
    "Categories" : "קטגוריות",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "This week" : "השבוע",
    "This month" : "החודש",
    "Delete note" : "מחיקת הערה",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Details" : "פרטים",
    "Preview" : "תצוגה מקדימה",
    "Edit" : "עריכה",
    "Category" : "קטגוריה",
    "Uncategorized" : "ללא קטגוריה",
    "Saving failed!" : "השמירה נכשלה!",
    "_%n word_::_%n words_" : ["%n מילה","%n מילים","%n מילים","%n מילים"],
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
